# -*- coding: utf-8 -*-

from zope.i18nmessageid import MessageFactory
MF = MessageFactory('dolmen.app.viewselector')

from dolmen.app.viewselector.interfaces import IViewSelector
from dolmen.app.viewselector.menu import SelectableViewsMenu
